# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .theme_color import ThemeColor


class TextFormatModel(UniversalBaseModel):
    bold: typing.Optional[bool] = None
    color_hex: typing.Optional[str] = pydantic.Field(default=None)
    """
    Text color as hex string (e.g., '#FF0000'). Use either color_hex or color_theme, not both.
    """

    color_theme: typing.Optional[ThemeColor] = pydantic.Field(default=None)
    """
    Text color as theme reference. Use either color_hex or color_theme, not both.
    """

    font_family: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="fontFamily")] = None
    font_size: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="fontSize")] = None
    italic: typing.Optional[bool] = None
    strikethrough: typing.Optional[bool] = None
    underline: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
